AdditionalLimit class

List of limits that are specific to a given InstanceType and for each of it's InstanceRole .

Constructors

AdditionalLimit({String? limitName, List<String>? limitValues})
AdditionalLimit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
limitName → String?
Name of Additional Limit is specific to a given InstanceType and for each of it's InstanceRole etc.
Attributes and their details:
final
limitValues → List<String>?
Value for given AdditionalLimit$LimitName .
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited