AdvancedSecurityOptions class

Specifies the advanced security configuration: whether advanced security is enabled, whether the internal database option is enabled.

Constructors

AdvancedSecurityOptions({bool? enabled, bool? internalUserDatabaseEnabled, SAMLOptionsOutput? sAMLOptions})
AdvancedSecurityOptions.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
True if advanced security is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
internalUserDatabaseEnabled → bool?
True if the internal user database is enabled.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sAMLOptions → SAMLOptionsOutput?
Describes the SAML application configured for a domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited