AdvancedSecurityOptionsStatus class

Specifies the status of advanced security options for the specified Elasticsearch domain.

Constructors

AdvancedSecurityOptionsStatus({required AdvancedSecurityOptions options, required OptionStatus status})
AdvancedSecurityOptionsStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → AdvancedSecurityOptions
Specifies advanced security options for the specified Elasticsearch domain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OptionStatus
Status of the advanced security options for the specified Elasticsearch domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited