CreateOutboundCrossClusterSearchConnectionResponse class

The result of a CreateOutboundCrossClusterSearchConnection request. Contains the details of the newly created cross-cluster search connection.

Constructors

CreateOutboundCrossClusterSearchConnectionResponse({String? connectionAlias, OutboundCrossClusterSearchConnectionStatus? connectionStatus, String? crossClusterSearchConnectionId, DomainInformation? destinationDomainInfo, DomainInformation? sourceDomainInfo})
CreateOutboundCrossClusterSearchConnectionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

connectionAlias → String?
Specifies the connection alias provided during the create connection request.
final
connectionStatus → OutboundCrossClusterSearchConnectionStatus?
Specifies the OutboundCrossClusterSearchConnectionStatus for the newly created connection.
final
crossClusterSearchConnectionId → String?
Unique id for the created outbound connection, which is used for subsequent operations on connection.
final
destinationDomainInfo → DomainInformation?
Specifies the DomainInformation for the destination Elasticsearch domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDomainInfo → DomainInformation?
Specifies the DomainInformation for the source Elasticsearch domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited