DomainEndpointOptions class

Options to configure endpoint for the Elasticsearch domain.

Constructors

DomainEndpointOptions({String? customEndpoint, String? customEndpointCertificateArn, bool? customEndpointEnabled, bool? enforceHTTPS, TLSSecurityPolicy? tLSSecurityPolicy})
DomainEndpointOptions.fromJson(Map<String, dynamic> json)
factory

Properties

customEndpoint → String?
Specify the fully qualified domain for your custom endpoint.
final
customEndpointCertificateArn → String?
Specify ACM certificate ARN for your custom endpoint.
final
customEndpointEnabled → bool?
Specify if custom endpoint should be enabled for the Elasticsearch domain.
final
enforceHTTPS → bool?
Specify if only HTTPS endpoint should be enabled for the Elasticsearch domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tLSSecurityPolicy → TLSSecurityPolicy?
Specify the TLS security policy that needs to be applied to the HTTPS endpoint of Elasticsearch domain.
It can be one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited