DomainEndpointOptionsStatus class

The configured endpoint options for the domain and their current status.

Constructors

DomainEndpointOptionsStatus({required DomainEndpointOptions options, required OptionStatus status})
DomainEndpointOptionsStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → DomainEndpointOptions
Options to configure endpoint for the Elasticsearch domain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OptionStatus
The status of the endpoint options for the Elasticsearch domain. See OptionStatus for the status information that's included.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited