ElasticsearchVersionStatus class

Status of the Elasticsearch version options for the specified Elasticsearch domain.

Constructors

ElasticsearchVersionStatus({required String options, required OptionStatus status})
ElasticsearchVersionStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → String
Specifies the Elasticsearch version for the specified Elasticsearch domain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OptionStatus
Specifies the status of the Elasticsearch version options for the specified Elasticsearch domain.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited