EncryptionAtRestOptions class

Specifies the Encryption At Rest Options.

Constructors

EncryptionAtRestOptions({bool? enabled, String? kmsKeyId})
EncryptionAtRestOptions.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
Specifies the option to enable Encryption At Rest.
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
Specifies the KMS Key ID for Encryption At Rest options.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited