GetPackageVersionHistoryResponse class

Container for response returned by GetPackageVersionHistory operation.

Constructors

GetPackageVersionHistoryResponse({String? nextToken, String? packageID, List<PackageVersionHistory>? packageVersionHistoryList})
GetPackageVersionHistoryResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
final
packageID → String?
final
packageVersionHistoryList → List<PackageVersionHistory>?
List of PackageVersionHistory objects.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited