GetUpgradeHistoryResponse class

Container for response returned by GetUpgradeHistory operation.

Constructors

GetUpgradeHistoryResponse({String? nextToken, List<UpgradeHistory>? upgradeHistories})
GetUpgradeHistoryResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
Pagination token that needs to be supplied to the next call to get the next page of results
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upgradeHistories → List<UpgradeHistory>?
A list of UpgradeHistory objects corresponding to each Upgrade or Upgrade Eligibility Check performed on a domain returned as part of GetUpgradeHistoryResponse object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited