InboundCrossClusterSearchConnectionStatus class

Specifies the coonection status of an inbound cross-cluster search connection.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
Specifies verbose information for the inbound connection status.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → InboundCrossClusterSearchConnectionStatusCode?
The state code for inbound connection. This can be one of the following:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited