InstanceCountLimits class

InstanceCountLimits represents the limits on number of instances that be created in Amazon Elasticsearch for given InstanceType.

Constructors

InstanceCountLimits({int? maximumInstanceCount, int? minimumInstanceCount})
InstanceCountLimits.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumInstanceCount → int?
final
minimumInstanceCount → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited