ListDomainNamesResponse class

The result of a ListDomainNames operation. Contains the names of all Elasticsearch domains owned by this account.

Constructors

ListDomainNamesResponse({List<DomainInfo>? domainNames})
ListDomainNamesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

domainNames → List<DomainInfo>?
List of Elasticsearch domain names.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited