ListPackagesForDomainResponse class

Container for response parameters to ListPackagesForDomain operation.

Constructors

ListPackagesForDomainResponse({List<DomainPackageDetails>? domainPackageDetailsList, String? nextToken})
ListPackagesForDomainResponse.fromJson(Map<String, dynamic> json)
factory

Properties

domainPackageDetailsList → List<DomainPackageDetails>?
List of DomainPackageDetails objects.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
Pagination token that needs to be supplied to the next call to get the next page of results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited