LogPublishingOptionsStatus class

The configured log publishing options for the domain and their current status.

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → Map<LogType, LogPublishingOption>?
The log publishing options configured for the Elasticsearch domain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OptionStatus?
The status of the log publishing options for the Elasticsearch domain. See OptionStatus for the status information that's included.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited