MasterUserOptions class

Credentials for the master user: username and password, ARN, or both.

Constructors

MasterUserOptions({String? masterUserARN, String? masterUserName, String? masterUserPassword})

Properties

hashCode → int
The hash code for this object.
no setterinherited
masterUserARN → String?
ARN for the master user (if IAM is enabled).
final
masterUserName → String?
The master user's username, which is stored in the Amazon Elasticsearch Service domain's internal database.
final
masterUserPassword → String?
The master user's password, which is stored in the Amazon Elasticsearch Service domain's internal database.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited