OptionStatus class

Provides the current status of the entity.

Constructors

OptionStatus({required DateTime creationDate, required OptionState state, required DateTime updateDate, bool? pendingDeletion, int? updateVersion})
OptionStatus.fromJson(Map<String, dynamic> json)
factory

Properties

creationDate → DateTime
Timestamp which tells the creation date for the entity.
final
hashCode → int
The hash code for this object.
no setterinherited
pendingDeletion → bool?
Indicates whether the Elasticsearch domain is being deleted.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → OptionState
Provides the OptionState for the Elasticsearch domain.
final
updateDate → DateTime
Timestamp which tells the last updated time for the entity.
final
updateVersion → int?
Specifies the latest version for the entity.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited