PackageSource class

The S3 location for importing the package specified as S3BucketName and S3Key

Constructors

PackageSource({String? s3BucketName, String? s3Key})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3BucketName → String?
Name of the bucket containing the package.
final
s3Key → String?
Key (file name) of the package.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited