PackageVersionHistory class

Details of a package version.

Constructors

PackageVersionHistory({String? commitMessage, DateTime? createdAt, String? packageVersion})
PackageVersionHistory.fromJson(Map<String, dynamic> json)
factory

Properties

commitMessage → String?
A message associated with the version.
final
createdAt → DateTime?
Timestamp which tells creation time of the package version.
final
hashCode → int
The hash code for this object.
no setterinherited
packageVersion → String?
Version of the package.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited