PurchaseReservedElasticsearchInstanceOfferingResponse class

Represents the output of a PurchaseReservedElasticsearchInstanceOffering operation.

Constructors

PurchaseReservedElasticsearchInstanceOfferingResponse({String? reservationName, String? reservedElasticsearchInstanceId})
PurchaseReservedElasticsearchInstanceOfferingResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
reservationName → String?
The customer-specified identifier used to track this reservation.
final
reservedElasticsearchInstanceId → String?
Details of the reserved Elasticsearch instance which was purchased.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited