RecurringCharge class

Contains the specific price and frequency of a recurring charges for a reserved Elasticsearch instance, or for a reserved Elasticsearch instance offering.

Constructors

RecurringCharge({double? recurringChargeAmount, String? recurringChargeFrequency})
RecurringCharge.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
recurringChargeAmount → double?
The monetary amount of the recurring charge.
final
recurringChargeFrequency → String?
The frequency of the recurring charge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited