ReservedElasticsearchInstanceOffering class

Details of a reserved Elasticsearch instance offering.

Constructors

ReservedElasticsearchInstanceOffering({String? currencyCode, int? duration, ESPartitionInstanceType? elasticsearchInstanceType, double? fixedPrice, ReservedElasticsearchInstancePaymentOption? paymentOption, List<RecurringCharge>? recurringCharges, String? reservedElasticsearchInstanceOfferingId, double? usagePrice})
ReservedElasticsearchInstanceOffering.fromJson(Map<String, dynamic> json)
factory

Properties

currencyCode → String?
The currency code for the reserved Elasticsearch instance offering.
final
duration → int?
The duration, in seconds, for which the offering will reserve the Elasticsearch instance.
final
elasticsearchInstanceType → ESPartitionInstanceType?
The Elasticsearch instance type offered by the reserved instance offering.
final
fixedPrice → double?
The upfront fixed charge you will pay to purchase the specific reserved Elasticsearch instance offering.
final
hashCode → int
The hash code for this object.
no setterinherited
paymentOption → ReservedElasticsearchInstancePaymentOption?
Payment option for the reserved Elasticsearch instance offering
final
recurringCharges → List<RecurringCharge>?
The charge to your account regardless of whether you are creating any domains using the instance offering.
final
reservedElasticsearchInstanceOfferingId → String?
The Elasticsearch reserved instance offering identifier.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usagePrice → double?
The rate you are charged for each hour the domain that is using the offering is running.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited