SAMLOptionsInput class

Specifies the SAML application configuration for the domain.

Constructors

SAMLOptionsInput({bool? enabled, SAMLIdp? idp, String? masterBackendRole, String? masterUserName, String? rolesKey, int? sessionTimeoutMinutes, String? subjectKey})

Properties

enabled → bool?
True if SAML is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
idp → SAMLIdp?
Specifies the SAML Identity Provider's information.
final
masterBackendRole → String?
The backend role to which the SAML master user is mapped to.
final
masterUserName → String?
The SAML master username, which is stored in the Amazon Elasticsearch Service domain's internal database.
final
rolesKey → String?
The key to use for matching the SAML Roles attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionTimeoutMinutes → int?
The duration, in minutes, after which a user session becomes inactive. Acceptable values are between 1 and 1440, and the default value is 60.
final
subjectKey → String?
The key to use for matching the SAML Subject attribute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited