SAMLOptionsOutput class

Describes the SAML application configured for the domain.

Constructors

SAMLOptionsOutput({bool? enabled, SAMLIdp? idp, String? rolesKey, int? sessionTimeoutMinutes, String? subjectKey})
SAMLOptionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

enabled → bool?
True if SAML is enabled.
final
hashCode → int
The hash code for this object.
no setterinherited
idp → SAMLIdp?
Describes the SAML Identity Provider's information.
final
rolesKey → String?
The key used for matching the SAML Roles attribute.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionTimeoutMinutes → int?
The duration, in minutes, after which a user session becomes inactive.
final
subjectKey → String?
The key used for matching the SAML Subject attribute.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited