ServiceSoftwareOptions class

The current options of an Elasticsearch domain service software options.

Constructors

ServiceSoftwareOptions({DateTime? automatedUpdateDate, bool? cancellable, String? currentVersion, String? description, String? newVersion, bool? optionalDeployment, bool? updateAvailable, DeploymentStatus? updateStatus})
ServiceSoftwareOptions.fromJson(Map<String, dynamic> json)
factory

Properties

automatedUpdateDate → DateTime?
Timestamp, in Epoch time, until which you can manually request a service software update. After this date, we automatically update your service software.
final
cancellable → bool?
True if you are able to cancel your service software version update. False if you are not able to cancel your service software version.
final
currentVersion → String?
The current service software version that is present on the domain.
final
description → String?
The description of the UpdateStatus.
final
hashCode → int
The hash code for this object.
no setterinherited
newVersion → String?
The new service software version if one is available.
final
optionalDeployment → bool?
True if a service software is never automatically updated. False if a service software is automatically updated after AutomatedUpdateDate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateAvailable → bool?
True if you are able to update you service software version. False if you are not able to update your service software version.
final
updateStatus → DeploymentStatus?
The status of your service software update. This field can take the following values: ELIGIBLE, PENDING_UPDATE, IN_PROGRESS, COMPLETED, and NOT_ELIGIBLE.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited