SnapshotOptionsStatus class

Status of a daily automated snapshot.

Constructors

SnapshotOptionsStatus({required SnapshotOptions options, required OptionStatus status})
SnapshotOptionsStatus.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → SnapshotOptions
Specifies the daily snapshot options specified for the Elasticsearch domain.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → OptionStatus
Specifies the status of a daily automated snapshot.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited