StorageTypeLimit class

Limits that are applicable for given storage type.

Constructors

StorageTypeLimit({String? limitName, List<String>? limitValues})
StorageTypeLimit.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
limitName → String?
Name of storage limits that are applicable for given storage type. If StorageType is ebs, following storage options are applicable
final
limitValues → List<String>?
Values for the StorageTypeLimit$LimitName .
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited