UpdateElasticsearchDomainConfigResponse class

The result of an UpdateElasticsearchDomain request. Contains the status of the Elasticsearch domain being updated.

Properties

domainConfig → ElasticsearchDomainConfig
The status of the updated Elasticsearch domain.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited